Add ossl_ conf symbols

Partial fix for #12964

Reviewed-by: Paul Dale <pauli@openssl.org>
(Merged from https://github.com/openssl/openssl/pull/14473)
diff --git a/crypto/comp/c_zlib.c b/crypto/comp/c_zlib.c
index 6d893c0..aa29862 100644
--- a/crypto/comp/c_zlib.c
+++ b/crypto/comp/c_zlib.c
@@ -244,7 +244,7 @@
                 zlib_loaded++;
 
             if (!OPENSSL_init_crypto(OPENSSL_INIT_ZLIB, NULL)) {
-                comp_zlib_cleanup_int();
+                ossl_comp_zlib_cleanup();
                 return meth;
             }
             if (zlib_loaded)
@@ -259,7 +259,7 @@
     return meth;
 }
 
-void comp_zlib_cleanup_int(void)
+void ossl_comp_zlib_cleanup(void)
 {
 #ifdef ZLIB_SHARED
     DSO_free(zlib_dso);
diff --git a/crypto/conf/conf_local.h b/crypto/conf/conf_local.h
index 1bc9c70..9961010 100644
--- a/crypto/conf/conf_local.h
+++ b/crypto/conf/conf_local.h
@@ -7,5 +7,4 @@
  * https://www.openssl.org/source/license.html
  */
 
-void conf_add_ssl_module(void);
-
+void ossl_config_add_ssl_module(void);
diff --git a/crypto/conf/conf_mall.c b/crypto/conf/conf_mall.c
index 5d24a36..50e7038 100644
--- a/crypto/conf/conf_mall.c
+++ b/crypto/conf/conf_mall.c
@@ -32,7 +32,7 @@
     ENGINE_add_conf_module();
 #endif
     EVP_add_alg_module();
-    conf_add_ssl_module();
+    ossl_config_add_ssl_module();
     ossl_provider_add_conf_module();
     ossl_random_add_conf_module();
 }
diff --git a/crypto/conf/conf_mod.c b/crypto/conf/conf_mod.c
index b42eb36..93e0fa5 100644
--- a/crypto/conf/conf_mod.c
+++ b/crypto/conf/conf_mod.c
@@ -485,7 +485,7 @@
         return 0;
 }
 
-void conf_modules_free_int(void)
+void ossl_config_modules_free(void)
 {
     CONF_modules_finish();
     CONF_modules_unload(1);
diff --git a/crypto/conf/conf_sap.c b/crypto/conf/conf_sap.c
index ffd9e9c..1969f0d 100644
--- a/crypto/conf/conf_sap.c
+++ b/crypto/conf/conf_sap.c
@@ -40,7 +40,7 @@
 }
 #endif
 
-int openssl_config_int(const OPENSSL_INIT_SETTINGS *settings)
+int ossl_config_int(const OPENSSL_INIT_SETTINGS *settings)
 {
     int ret = 0;
     const char *filename;
@@ -55,7 +55,7 @@
     flags = settings ? settings->flags : DEFAULT_CONF_MFLAGS;
 
 #ifdef OPENSSL_INIT_DEBUG
-    fprintf(stderr, "OPENSSL_INIT: openssl_config_int(%s, %s, %lu)\n",
+    fprintf(stderr, "OPENSSL_INIT: ossl_config_int(%s, %s, %lu)\n",
             filename, appname, flags);
 #endif
 
@@ -66,7 +66,7 @@
     return ret;
 }
 
-void openssl_no_config_int(void)
+void ossl_no_config_int(void)
 {
     openssl_configured = 1;
 }
diff --git a/crypto/conf/conf_ssl.c b/crypto/conf/conf_ssl.c
index a4b35ba..d32289e 100644
--- a/crypto/conf/conf_ssl.c
+++ b/crypto/conf/conf_ssl.c
@@ -176,7 +176,7 @@
     *arg = cmd[idx].arg;
 }
 
-void conf_add_ssl_module(void)
+void ossl_config_add_ssl_module(void)
 {
     CONF_module_add("ssl_conf", ssl_module_init, ssl_module_free);
 }
diff --git a/crypto/objects/obj_dat.c b/crypto/objects/obj_dat.c
index a3cb874..87ddb3f 100644
--- a/crypto/objects/obj_dat.c
+++ b/crypto/objects/obj_dat.c
@@ -150,7 +150,7 @@
     OPENSSL_free(a);
 }
 
-void obj_cleanup_int(void)
+void ossl_obj_cleanup_int(void)
 {
     if (added == NULL)
         return;
diff --git a/include/crypto/objects.h b/include/crypto/objects.h
index 7db718f..2a20b25 100644
--- a/include/crypto/objects.h
+++ b/include/crypto/objects.h
@@ -9,4 +9,4 @@
 
 #include <openssl/objects.h>
 
-void obj_cleanup_int(void);
+void ossl_obj_cleanup_int(void);
diff --git a/include/internal/comp.h b/include/internal/comp.h
index e585a5c..1a005e8 100644
--- a/include/internal/comp.h
+++ b/include/internal/comp.h
@@ -9,4 +9,4 @@
 
 #include <openssl/comp.h>
 
-void comp_zlib_cleanup_int(void);
+void ossl_comp_zlib_cleanup(void);
diff --git a/include/internal/conf.h b/include/internal/conf.h
index 81968c9..8c6c29c 100644
--- a/include/internal/conf.h
+++ b/include/internal/conf.h
@@ -24,8 +24,8 @@
     unsigned long flags;
 };
 
-int openssl_config_int(const OPENSSL_INIT_SETTINGS *);
-void openssl_no_config_int(void);
-void conf_modules_free_int(void);
+int ossl_config_int(const OPENSSL_INIT_SETTINGS *);
+void ossl_no_config_int(void);
+void ossl_config_modules_free(void);
 
 #endif
diff --git a/crypto/init.c b/crypto/init.c
index 4bef667..aa97579 100644
--- a/crypto/init.c
+++ b/crypto/init.c
@@ -235,22 +235,22 @@
 static const OPENSSL_INIT_SETTINGS *conf_settings = NULL;
 DEFINE_RUN_ONCE_STATIC(ossl_init_config)
 {
-    int ret = openssl_config_int(NULL);
+    int ret = ossl_config_int(NULL);
 
     config_inited = 1;
     return ret;
 }
 DEFINE_RUN_ONCE_STATIC_ALT(ossl_init_config_settings, ossl_init_config)
 {
-    int ret = openssl_config_int(conf_settings);
+    int ret = ossl_config_int(conf_settings);
 
     config_inited = 1;
     return ret;
 }
 DEFINE_RUN_ONCE_STATIC_ALT(ossl_init_no_config, ossl_init_config)
 {
-    OSSL_TRACE(INIT, "openssl_no_config_int()\n");
-    openssl_no_config_int();
+    OSSL_TRACE(INIT, "ossl_no_config_int()\n");
+    ossl_no_config_int();
     config_inited = 1;
     return 1;
 }
@@ -385,8 +385,8 @@
 
 #ifndef OPENSSL_NO_COMP
     if (zlib_inited) {
-        OSSL_TRACE(INIT, "OPENSSL_cleanup: comp_zlib_cleanup_int()\n");
-        comp_zlib_cleanup_int();
+        OSSL_TRACE(INIT, "OPENSSL_cleanup: ossl_comp_zlib_cleanup()\n");
+        ossl_comp_zlib_cleanup();
     }
 #endif
 
@@ -406,16 +406,16 @@
      * must be called before engine_cleanup_int()
      * - ENGINEs use CRYPTO_EX_DATA and therefore, must be cleaned up
      * before the ex data handlers are wiped during default ossl_lib_ctx deinit.
      * - conf_modules_free_int() can end up in ENGINE code so must be called
      * before engine_cleanup_int()
      * - ENGINEs and additional EVP algorithms might use added OIDs names so
      * obj_cleanup_int() must be called last
      */
     OSSL_TRACE(INIT, "OPENSSL_cleanup: ossl_rand_cleanup_int()\n");
     ossl_rand_cleanup_int();
 
-    OSSL_TRACE(INIT, "OPENSSL_cleanup: conf_modules_free_int()\n");
-    conf_modules_free_int();
+    OSSL_TRACE(INIT, "OPENSSL_cleanup: ossl_config_modules_free()\n");
+    ossl_config_modules_free();
 
 #ifndef OPENSSL_NO_ENGINE
     OSSL_TRACE(INIT, "OPENSSL_cleanup: engine_cleanup_int()\n");
@@ -438,8 +438,8 @@
     OSSL_TRACE(INIT, "OPENSSL_cleanup: evp_cleanup_int()\n");
     evp_cleanup_int();
 
-    OSSL_TRACE(INIT, "OPENSSL_cleanup: obj_cleanup_int()\n");
-    obj_cleanup_int();
+    OSSL_TRACE(INIT, "OPENSSL_cleanup: ossl_obj_cleanup_int()\n");
+    ossl_obj_cleanup_int();
 
     OSSL_TRACE(INIT, "OPENSSL_cleanup: err_int()\n");
     err_cleanup();
@@ -406,16 +406,16 @@
      * - ENGINEs use CRYPTO_EX_DATA and therefore, must be cleaned up
      * before the ex data handlers are wiped during default ossl_lib_ctx deinit.
-     * - conf_modules_free_int() can end up in ENGINE code so must be called
+     * - ossl_config_modules_free() can end up in ENGINE code so must be called
      * before engine_cleanup_int()
      * - ENGINEs and additional EVP algorithms might use added OIDs names so
@@ -406,16 +406,16 @@
      * before engine_cleanup_int()
      * - ENGINEs and additional EVP algorithms might use added OIDs names so
-     * obj_cleanup_int() must be called last
+     * ossl_obj_cleanup_int() must be called last
      */
     OSSL_TRACE(INIT, "OPENSSL_cleanup: ossl_rand_cleanup_int()\n");